| Title: | Re-Scale Vectors and Time-Series Features |
|---|---|
| Description: | Provides standardized access to a range of re-scaling methods for numerical vectors and time-series features calculated within the 'theft' ecosystem. |
| Authors: | Trent Henderson [cre, aut] |
| Maintainer: | Trent Henderson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-06-03 09:49:30 UTC |
| Source: | https://github.com/hendersontrent/normaliser |
maxabs_scaler(x)maxabs_scaler(x)
x |
|
numeric vector
Trent Henderson
minmax_scaler(x)minmax_scaler(x)
x |
|
numeric vector
Trent Henderson
'normalise()' and 'normalize()' are synonyms.
normalise( data, norm_method = c("zScore", "Sigmoid", "RobustSigmoid", "MinMax", "MaxAbs"), unit_int = FALSE ) normalize( data, norm_method = c("zScore", "Sigmoid", "RobustSigmoid", "MinMax", "MaxAbs"), unit_int = FALSE )normalise( data, norm_method = c("zScore", "Sigmoid", "RobustSigmoid", "MinMax", "MaxAbs"), unit_int = FALSE ) normalize( data, norm_method = c("zScore", "Sigmoid", "RobustSigmoid", "MinMax", "MaxAbs"), unit_int = FALSE )
data |
either a |
norm_method |
|
unit_int |
|
either an object of class feature_calculations object or a numeric vector depending on the data type supplied to data
Trent Henderson
robustsigmoid_scaler(x)robustsigmoid_scaler(x)
x |
|
numeric vector
Trent Henderson
Fulcher, Ben D., Little, Max A., and Jones, Nick S. Highly Comparative Time-Series Analysis: The Empirical Structure of Time Series and Their Methods. Journal of The Royal Society Interface 10(83), (2013).
sigmoid_scaler(x)sigmoid_scaler(x)
x |
|
numeric vector
Trent Henderson
zscore_scaler(x)zscore_scaler(x)
x |
|
numeric vector
Trent Henderson